@@ -245,6 +245,8 @@ should_purge_file (GFile        *file,
                                   G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,
                                   cancellable,
                                   NULL);
+        if (!info)
+                return FALSE;
 
         date = g_file_info_get_deletion_date (info);
         if (date == NULL) {
@@ -270,18 +272,7 @@ out:
         return should_purge;
 }
 
-typedef struct {
-        gint ref_count;
-        GFile           *file;
-        GCancellable    *cancellable;
-        GDateTime       *old;
-        gboolean         dry_run;
-        gboolean         trash;
-        gchar           *name;
-        gint             depth;
-} DeleteData;
-
-static DeleteData *
+DeleteData *
 delete_data_new (GFile        *file,
                  GCancellable *cancellable,
                  GDateTime    *old,
@@ -311,7 +302,7 @@ delete_data_ref (DeleteData *data)
   return data;
 }
 
-static void
+void
 delete_data_unref (DeleteData *data)
 {
         data->ref_count -= 1;
@@ -326,8 +317,6 @@ delete_data_unref (DeleteData *data)
         g_free (data);
 }
 
-static void delete_recursively_by_age (DeleteData *data);
-
 static void
 delete_batch (GObject      *source,
               GAsyncResult *res,
@@ -405,7 +394,6 @@ delete_subdir (GObject      *source,
         if (error) {
                 if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_NOT_DIRECTORY))
                         g_warning ("Failed to enumerate children of %s: %s\n", data->name, error->message);
-                g_error_free (error);
         }
         if (enumerator) {
                 g_file_enumerator_next_files_async (enumerator, 20,
@@ -413,11 +401,61 @@ delete_subdir (GObject      *source,
                                                     data->cancellable,
                                                     delete_batch,
                                                     delete_data_ref (data));
+        } else if (data->depth > 0 && g_error_matches (error, G_IO_ERROR, G_IO_ERROR_NOT_DIRECTORY)) {
+                if ((data->trash && data->depth > 1) ||
+                     should_purge_file (data->file, data->cancellable, data->old)) {
+                        g_debug ("Purging %s leaf node", data->name);
+                        if (!data->dry_run) {
+                                g_file_delete (data->file, data->cancellable, NULL);
+                        }
+                }
         }
+
+        if (error)
+                g_error_free (error);
         delete_data_unref (data);
 }
 
 static void
+delete_subdir_check_symlink (GObject      *source,
+                             GAsyncResult *res,
+                             gpointer      user_data)
+{
+        GFile *file = G_FILE (source);
+        DeleteData *data = user_data;
+        GFileInfo *info;
+        GFileType type;
+
+        info = g_file_query_info_finish (file, res, NULL);
+        if (!info) {
+                delete_data_unref (data);
+                return;
+        }
+
+        type = g_file_info_get_file_type (info);
+        g_object_unref (info);
+
+        if (type == G_FILE_TYPE_DIRECTORY) {
+                g_file_enumerate_children_async (data->file,
+                                                 G_FILE_ATTRIBUTE_STANDARD_NAME ","
+                                                 G_FILE_ATTRIBUTE_STANDARD_TYPE,
+                                                 G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,
+                                                 0,
+                                                 data->cancellable,
+                                                 delete_subdir,
+                                                 delete_data_ref (data));
+        } else if (type == G_FILE_TYPE_SYMBOLIC_LINK) {
+                if (should_purge_file (data->file, data->cancellable, data->old)) {
+                        g_debug ("Purging %s leaf node", data->name);
+                        if (!data->dry_run) {
+                                g_file_delete (data->file, data->cancellable, NULL);
+                        }
+                }
+        }
+        delete_data_unref (data);
+}
+
+void
 delete_recursively_by_age (DeleteData *data)
 {
         if (data->trash && (data->depth == 1) &&
@@ -426,14 +464,13 @@ delete_recursively_by_age (DeleteData *data)
                 return;
         }
 
-        g_file_enumerate_children_async (data->file,
-                                         G_FILE_ATTRIBUTE_STANDARD_NAME ","
-                                         G_FILE_ATTRIBUTE_STANDARD_TYPE,
-                                         G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,
-                                         0,
-                                         data->cancellable,
-                                         delete_subdir,
-                                         delete_data_ref (data));
+        g_file_query_info_async (data->file,
+                                 G_FILE_ATTRIBUTE_STANDARD_TYPE,
+                                 G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,
+                                 0,
+                                 data->cancellable,
+                                 delete_subdir_check_symlink,
+                                 delete_data_ref (data));
 }
 
 void
