@@ -1889,7 +1889,7 @@ gsd_wacom_device_get_area (GsdWacomDevice *device)
 				 XA_INTEGER, &realtype, &realformat, &nitems,
 				 &bytes_after, &data);
 	if (gdk_error_trap_pop () || rc != Success || realtype == None || bytes_after != 0 || nitems != 4) {
-		XCloseDevice (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), xdevice);
+		xdevice_close (xdevice);
 		return NULL;
 	}
 
@@ -1898,7 +1898,78 @@ gsd_wacom_device_get_area (GsdWacomDevice *device)
 		device_area[i] = ((long *)data)[i];
 
 	XFree (data);
-	XCloseDevice (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), xdevice);
+	xdevice_close (xdevice);
+
+	return device_area;
+}
+
+static gboolean
+fill_old_axis (int    device_id,
+	       gint  *items)
+{
+	int ndevices, i;
+	XDeviceInfoPtr list, slist;
+	gboolean retval = FALSE;
+
+	slist = list = (XDeviceInfoPtr) XListInputDevices (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), &ndevices);
+
+	for (i = 0; i < ndevices; i++, list++) {
+		XAnyClassPtr any = (XAnyClassPtr) (list->inputclassinfo);
+		int j;
+
+		/* Core pointer and keyboard */
+		if (list->use == IsXKeyboard || list->use == IsXPointer)
+			continue;
+
+		if (list->id != device_id)
+			continue;
+
+		for (j = 0; j < list->num_classes; j++) {
+			if (any->class == ValuatorClass) {
+				XValuatorInfoPtr V = (XValuatorInfoPtr) any;
+				XAxisInfoPtr ax = (XAxisInfoPtr) V->axes;
+
+				if (V->num_axes >= 2) {
+					items[0] = ax[0].min_value;
+					items[2] = ax[0].max_value;
+					items[1] = ax[1].min_value;
+					items[3] = ax[1].max_value;
+					g_debug ("Found factory values for device calibration");
+					retval = TRUE;
+					break;
+				}
+			}
+
+			/*
+			 * Increment 'any' to point to the next item in the linked
+			 * list.  The length is in bytes, so 'any' must be cast to
+			 * a character pointer before being incremented.
+			 */
+			any = (XAnyClassPtr) ((char *) any + any->length);
+		}
+	}
+	XFreeDeviceList(slist);
+
+	return retval;
+}
+
+gint *
+gsd_wacom_device_get_default_area (GsdWacomDevice *device)
+{
+	int id;
+	gint *device_area;
+	gboolean ret;
+
+	g_return_val_if_fail (GSD_IS_WACOM_DEVICE (device), NULL);
+
+	g_object_get (device->priv->gdk_device, "device-id", &id, NULL);
+
+	device_area = g_new0 (int, 4);
+	ret = fill_old_axis (id, device_area);
+	if (!ret) {
+		g_free (device_area);
+		return NULL;
+	}
 
 	return device_area;
 }
